;          11/8/92
;          Brian Bushay
;          Bushay Custom Applications
;          1717 Emerson Ave N.
;          Minneapolis, MN 55411

proc_lib = "Sample"
Createlib proc_lib
Message "Building procedures Query by Dialog Sample"
? " Cr_RPT.sc"
; ================================================================================
; ============================== SampleReports()  ==============================
; ================================================================================
;
Proc SampleReports(DlgBoxProc.a)
              ;dlgBoxProc.a  the dialog proceedure to use
  Private ret,procname.a,
             queryProc.a,      ;Proceedure that has Query to be performed
             dlgTrigersProc.a, ;Proceedure to evaluate triggers generated by Dialog box
              location.a,      ; loacation to be transfered to query
              bgn.d,           ; begining date to transfer to Query
              end.d,           ; ending date to transfer to Query
              tag.a
  procname.a = "SampleReports"
  dlgTrigersProc.a = "AcceptAndQuery" ;use this proceedure for evaluating triggers generated in Dialog Box
  queryProc.a      = "SampleQuery"   ;Query to use for this report
  ;initialize variables
  bgn.d  = BlankDate()
  end.d  = BlankDate()
  location.a = ""
  tag.a      = ""    ;tag to return to with SelectControl

   ExecProc DlgBoxProc.a ;  Bring up Dialogbox
   ret = retval          ; capture return value
  If ret Then            ; Proceed with report
    ;place code for report here
  Else rtnmsg = "Report canceled"
  Endif
  ClearAll
EndProc

  WriteLib proc_lib SampleReports
  Release Procs SampleReports
  ?? ""

; ================================================================================
; ==============================SampleQuery()  ==============================
; ================================================================================
;  Query to use for Sample reprot
Proc SampleQuery()
  Private ret,procname.a
  procname.a = "SampleQuery"
     Message "Processing your Selectoin Criteria"
     ClearAll
     {Ask} Select "Courses"
       MoveTo [#] Check  ;Check all fields
       RangFieldEntry("Completion Date",bgn.d,end.d)
       If not QueryFieldEntry("Location",location.a) Then
          Return False
       Endif

     Do_It!
     If IsEmpty("Answer") Then
       tag.a = "Cancel"
       Message "No records found meeting your selection criteria"
       Return false
     Endif
     Return true
EndProc

  WriteLib proc_lib SampleQuery
  Release Procs SampleQuery
  ?? ""
; ================================================================================
; ==============================DlgEnterCtrlPlus ==============================
; ================================================================================
;
Proc DlgEnterCtrlPlus(triger.a,tag.a,event.y,elemnt.a)
  Private ret,procname.a
  procname.a = "DlgEnterCtrlPlus"
  Switch
    Case triger.a = "EVENT" and event.y["TYPE"] = "KEY":
      Release vars event.y["ScanCode"]
      Switch
        Case event.y["KeyCode"] = -59 : ;Help
         If IsAssigned(helpProc.y["DBoxHelp*"+procname.a]) Then
            ExecProc   helpProc.y["DBoxHelp*"+procname.a]
         Else
            ExecProc  helpProc.y["DialogBox*HlpProc"]
         Endif
         Return false
        Case event.y["KeyCode"] = 13 :
            If Search(tag.a,"Cancel,Ok") = 0 Then
            event.y["KeyCode"] = 9
          Endif
        Case Search("$",tag.a) = 1: ;no key translation if tag uses leading "$"
        Case event.y["KeyCode"] = -72 : ;up
            event.y["KeyCode"] = -15
        Case event.y["KeyCode"] = -80 : ;Down
            event.y["KeyCode"] = 9
      EndSwitch
    Case triger.a <> "EVENT":
      If IsAssigned(dlgTrigersProc.a) then
        ExecProc dlgTrigersProc.a
        return retval
      Endif
  EndSwitch
EndProc

  WriteLib proc_lib DlgEnterCtrlPlus
  Release Procs DlgEnterCtrlPlus
  ?? ""

; ================================================================================
; ==============================QueryFieldEntry()  ==============================
; ================================================================================
; Enters an alpha value into a field, Can include wild cards
Proc QueryFieldEntry(field.a,criteria.a)
  Private ret,procname.a
  procname.a = "QueryFieldEntry"
     MoveTo Field field.a
       tag.a = Field() ;tag assumed to be same as field name
       If not IsBlank([]) and Not IsBlank(criteria.a) Then Typein ", " Endif
       TypeIn criteria.a
       Left  ;triggers Widow() error if there is one
       If not IsBlank(Window()) Then
          Message "Selection Criteria Error! \""+ Window()+"\""
          CtrlBackSpace  ;Clear Field
          Return false
       Else Return True
       Endif
EndProc

  WriteLib proc_lib QueryFieldEntry
  Release Procs QueryFieldEntry
  ?? ""


; ================================================================================
; ==============================RangFieldEntry()  ==============================
; ================================================================================
; enter a begining and ending range into  a field
Proc RangFieldEntry(field.a,bgnval.v,endval.v)
  Private ret,procname.a
  procname.a = "RangFieldEntry"
   MoveTo Field field.a
   If Not IsBlank([]) Then ;check to see if current field needs a comma before additional entry
      If Not IsBlank(bgnval.v) or Not IsBlank(endval.v) Then
      TypeIn ","
      Endif
   Endif
   If not IsBlank(bgnval.v) Then
      If not IsBlank([]) Then TypeIn ", " Endif
      If Search("A",Type(bgnval.v)) >0 Then
        TypeIn ">= \""+bgnval.v+"\""
      Else
        TypeIn ">= "+Strval(bgnval.v)
      Endif
    Endif
   If not IsBlank(endval.v) Then
      If not IsBlank([]) Then TypeIn ", " Endif
      If Search("A",Type(endval.v)) >0 Then
        TypeIn "<= \""+endval.v+"\""
      Else
        TypeIn "<= "+Strval(endval.v)
      Endif
   Endif

EndProc

  WriteLib proc_lib RangFieldEntry
  Release Procs RangFieldEntry
  ?? ""

; ================================================================================
; ==============================AcceptAndQuery()  ==============================
; ================================================================================
; Proceedure to evaluate triggers generated for a DialgBox Proceedure
Proc AcceptAndQuery()
  Private ret,procname.a
  procname.a = "AcceptAndQuery"
  ret = true  ;default return var is true
  Switch
    Case triger.a = "ACCEPT":
      Switch
       OTherWise:
        ExecProc queryProc.a  ;perform this Query
        ret = retval
        If not ret Then
          SelectControl tag.a
        Endif
      EndSwitch
  EndSwitch
  Return ret

EndProc

  WriteLib proc_lib AcceptAndQuery
  Release Procs AcceptAndQuery
  ?? ""
; ================================================================================
; ==============================SampleDialog.box()  ==============================
; ================================================================================
; 
Proc SampleDialog.box()
  Private ret,procname.a
  procname.a = "SampleDialog.box"

    ; PaintPAL_Generated_Code_Begin(425751025)

  SHOWDIALOG "Enter Selection Criteria"
     PROC "DlgEnterCtrlPlus"
        KEY "Down", "Enter", "Up"
        TRIGGER "OPEN", "CLOSE", "ACCEPT", "CANCEL"

     @2,1 HEIGHT 12 WIDTH 51

     ; PaintPAL_Static_Text_Begin
     PAINTCANVAS FILL " " ATTRIBUTE 112 1,1,1,17
     @1,1
     ?? "Completion Date"
     PAINTCANVAS ATTRIBUTE 112 1,1,1,17
     ; PaintPAL_Static_Text_End

     ACCEPT @2,11 WIDTH 12
        "D"
        TAG "bgn date"
        TO bgn.d

     LABEL @2,3
        "Begin: "
        FOR "bgn date"

     ACCEPT @2,31 WIDTH 12
        "D"
        TAG "end date"
        TO end.d

     LABEL @2,25
        "End: "
        FOR "end date"

     ACCEPT @5,14 WIDTH 30
        "A50"
        TAG "Location"
        TO Location.a

     LABEL @5,3
        "Location: "
        FOR "Location"

     PUSHBUTTON @8,7 WIDTH 16
        "~B~egin Report"
        OK
        VALUE "Ok"
        TAG "Ok"
        TO control.a

     PUSHBUTTON @8,28 WIDTH 14
        "~C~ancel"
        CANCEL
        VALUE "Cancel"
        TAG "Cancel"
        TO control.a
  ENDDIALOG

  ; PaintPAL_Generated_Code_End(425751025)


EndProc

  WriteLib proc_lib SampleDialog.box
  Release Procs SampleDialog.box
  ?? ""
